Struct amazon_sp_services::models::appointment_slot::AppointmentSlot
source · [−]pub struct AppointmentSlot {
pub start_time: Option<String>,
pub end_time: Option<String>,
pub capacity: Option<i32>,
}Expand description
AppointmentSlot : A time window along with associated capacity in which the service can be performed.
Fields
start_time: Option<String>Time window start time in ISO 8601 format.
end_time: Option<String>Time window end time in ISO 8601 format.
capacity: Option<i32>Number of resources for which a slot can be reserved.
Implementations
sourceimpl AppointmentSlot
impl AppointmentSlot
sourcepub fn new() -> AppointmentSlot
pub fn new() -> AppointmentSlot
A time window along with associated capacity in which the service can be performed.